Adjust scrolling amount to make current cursor position visible.

- 0: Top.
- 0.5: Center.
- 1: Bottom.

When using to make a default/current item visible, consider using [ImGuiSetItemDefaultFocus] instead.
